@@ -1,6 +1,6 @@
 package Workflow::Persister::File;
 
-# $Id: File.pm 285 2007-06-18 19:57:58Z jonasbn $
+# $Id: File.pm 316 2007-07-04 19:17:50Z jonasbn $
 
 use strict;
 use base qw( Workflow::Persister );
@@ -205,21 +205,93 @@ serialized Perl data structure files.
 
 =head2 METHODS
 
-#=head3 constitute_object
+=head3 constitute_object
 
-#=head3 create_history
+This method deserializes an object.
 
-#=head3 create_workflow
+Takes a single parameter of an filesystem path pointing to an object
 
-#=head3 fetch_history
+Returns the re-instantiated object or dies.
 
-#=head3 fetch_workflow
+=head3 create_history
 
-#=head3 init
+Serializes history records associated with a workflow object
 
-#=head3 serialize_object
+Takes two parameters: a workflow object and an array of workflow history objects
 
-#=head3 update_workflow
+Returns: provided array of workflow history objects upon success
+
+=head3 create_workflow
+
+Serializes a workflow into the persistance entity configured by our workflow.
+
+Takes a single parameter: a workflow object
+
+Returns a single value, a id for unique identification of out serialized
+workflow for possible deserialization.
+
+=head3 fetch_history
+
+Deserializes history records associated with a workflow object
+
+Takes a single parameter: a workflow object
+
+Returns an array of workflow history objects upon success
+
+=head3 fetch_workflow
+
+Deserializes a workflow from the persistance entity configured by our workflow.
+
+Takes a single parameter: the unique id assigned to our workflow upon
+serialization (see L</create_workflow>).
+
+Returns a hashref consisting of two keys:
+
+=over
+
+=item * state, the workflows current state
+
+=item * last_update, date indicating last update
+
+=back
+
+=head3 init ( \%params )
+
+Method to initialize the persister object. Sets up the configured generators
+
+Throws a L<Workflow::Exception> if a valid filesystem path is not provided with
+the parameters.
+
+=head3 serialize_object
+
+Method that writes a given object to a given path.
+
+Takes two parameters: path (a filesystem path) and an object
+
+Throws L<Workflow::Exception> if unable to serialize the given object to the
+given path.
+
+Returns: Nothing
+
+=head3 update_workflow
+
+Updates a serialized workflow in the persistance entity configured by our
+workflow.
+
+Takes a single parameter: a workflow object
+
+Returns: Nothing
+
+=head1 TODO
+
+=over
+
+=item * exchange die for croak in L</constitute_object>
+
+=item * refactor L</constitute_object>, no checks are made on filesystem prior
+to deserialization attempt.
+
+=back
 
 =head1 SEE ALSO
 
@@ -227,11 +299,15 @@ L<Workflow::Persister>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2007 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
+
+Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+
+=cut
